@@ -1,27 +1,29 @@
-#!/usr/bin/env python2
+#!/usr/bin/python2
 
 import sys
 reload(sys)
 sys.setdefaultencoding('utf-8')
 
-sys.path.append('/usr/share/cinnamon/cinnamon-settings/modules')
-sys.path.append('/usr/share/cinnamon/cinnamon-settings/bin')
 import os
 import glob
 import gettext
-import gi
-gi.require_version('Gtk', '3.0')
-from gi.repository import Gio, Gtk, GObject, GdkPixbuf, GLib, Pango, Gdk, cairo
-import SettingsWidgets
-import capi
 import time
 import traceback
 import locale
 import urllib2
-import proxygsettings
 from functools import cmp_to_key
 import unicodedata
 
+import gi
+gi.require_version('Gtk', '3.0')
+from gi.repository import Gio, Gtk, Pango, Gdk
+
+sys.path.append('/usr/share/cinnamon/cinnamon-settings/modules')
+sys.path.append('/usr/share/cinnamon/cinnamon-settings/bin')
+import capi
+import proxygsettings
+import SettingsWidgets
+
 # i18n
 gettext.install("cinnamon", "/usr/share/locale")
 
@@ -65,7 +67,7 @@ CATEGORIES = [
 
 CONTROL_CENTER_MODULES = [
 #         Label                              Module ID                Icon                         Category      Keywords for filter
-    [_("Networking"),                       "network",            "cs-network",                 "hardware",      _("network, wireless, wifi, ethernet, broadband, internet")],
+    [_("Network"),                          "network",            "cs-network",                 "hardware",      _("network, wireless, wifi, ethernet, broadband, internet")],
     [_("Display"),                          "display",            "cs-display",                 "hardware",      _("display, screen, monitor, layout, resolution, dual, lcd")],
     [_("Color"),                            "color",              "cs-color",                   "hardware",      _("color, profile, display, printer, output")],
     [_("Graphics Tablet"),                  "wacom",              "cs-tablet",                  "hardware",      _("wacom, digitize, tablet, graphics, calibrate, stylus")]
@@ -108,10 +110,10 @@ class MainWindow:
             filtered_path = side_view.get_model().convert_path_to_child_path(selected_items[0])
             if filtered_path is not None:
                 self.go_to_sidepage(cat, filtered_path)
-    
+
     def _on_sidepage_hide_stack(self):
         self.stack_switcher.set_opacity(0)
-        
+
     def _on_sidepage_show_stack(self):
         self.stack_switcher.set_opacity(1)
 
@@ -160,17 +162,18 @@ class MainWindow:
 
         # Resize vertically depending on the height requested by the module
         use_height = WIN_HEIGHT
+        total_height = n.height + self.bar_heights + WIN_H_PADDING
         if not sidePage.size:
             # No height requested, resize vertically if the module is taller than the window
-            if n.height > WIN_HEIGHT:
-                use_height = n.height + self.bar_heights + WIN_H_PADDING
+            if total_height > WIN_HEIGHT:
+                use_height = total_height
             #self.window.resize(use_width, n.height + self.bar_heights + WIN_H_PADDING)
         elif sidePage.size > 0:
             # Height hardcoded by the module
             use_height = sidePage.size + self.bar_heights + WIN_H_PADDING
         elif sidePage.size == -1:
             # Module requested the window to fit it (i.e. shrink the window if necessary)
-            use_height = n.height + self.bar_heights + WIN_H_PADDING
+            use_height = total_height
 
         self.window.resize(use_width, use_height)
 
@@ -194,6 +197,9 @@ class MainWindow:
         self.header_stack.set_transition_duration(150)
         self.side_view_container = self.builder.get_object("category_box")
         self.side_view_sw = self.builder.get_object("side_view_sw")
+        context = self.side_view_sw.get_style_context()
+        context.add_class("cs-category-view")
+        context.add_class("view")
         self.side_view_sw.show_all()
         self.content_box = self.builder.get_object("content_box")
         self.content_box_sw = self.builder.get_object("content_box_sw")
@@ -439,15 +445,6 @@ class MainWindow:
 
         area.add_attribute(text_renderer, "text", 0)
 
-        css_provider = Gtk.CssProvider()
-        css_provider.load_from_data("GtkIconView {                             \
-                                         background-color: transparent;        \
-                                     }                                         \
-                                     GtkIconView.view.cell:selected {          \
-                                         background-color: @theme_selected_bg_color; \
-                                     }")
-        c = widget.get_style_context()
-        c.add_provider(css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
         self.side_view[category["id"]] = widget
         self.side_view_container.pack_start(self.side_view[category["id"]], False, False, 0)
         self.first_category_done = True
